<?php
// wcf imports
require_once(WCF_DIR.'lib/acp/package/plugin/AbstractPackageInstallationPlugin.class.php');

/**
 * This PIP updates or deletes styles. Use <style/> PIP for installing.
 *
 * @author		Martin Phlmann
 * @copyright	2009 Inovato, LLC <http://www.inovato.net>
 * @license		Creative Commons Attribution-Noncommercial-No Derivative Works 3.0 Unported <http://creativecommons.org/licenses/by-nc-nd/3.0/>
 * @package		net.inovato.wcf.style.updatepip
 */
class StyleUpdatePackageInstallationPlugin extends AbstractPackageInstallationPlugin
{
	public $tagName = 'styleupdate';
	public $tableName = 'style';

	/**
	 * @see PackageInstallationPlugin::install()
	 */
	public function install()
	{
		parent::install();
		require_once(WCF_DIR.'lib/data/style/StyleEditor.class.php');
		$instructions = $this->installation->getInstructions();
		$styles = $instructions['styleupdate'];
		if (count($styles) && isset($styles['cdata'])) $styles = array($styles);

		// Install each <styleupdate>-tag from package.xml
		foreach ($styles as $styleData)
		{
			// we just perform style updates or deletes
			if (!isset($styleData['name']) || !$styleData['name'])
				return false;
			
			// get 1st installed style w/ name and package id matching the xml data
			require_once(WCF_DIR.'lib/data/style/StyleEditor.class.php');
			$sql = "SELECT	*
					FROM	wcf".WCF_N."_style
					WHERE	packageID = ".$this->installation->getPackageID()."
						AND	styleName = '".escapeString($styleData['name'])."'";
			$row = WCF::getDB()->getFirstRow($sql);
			
			if (empty($row['styleID']))
			{
				return false;
			}
			
			// load old style
			$style = new StyleEditor(null, $row);
			
			// delete the templates linked to this style
// (MP) I don't think this is a wise idea, because one nver knows who actually installed this template pack!
//			if ($style->templatePackID > 0)
//			{
//				$template = new TemplatePackEditor($style->templatePackID);
//				$template->delete();
//			}
			
			// delete the style if requested
			if (isset($styleData['delete'])) {
				
				// default style deleted
				if ($style->isDefault)
				{
					$sql = "SELECT		*
						FROM		wcf".WCF_N."_style
						ORDER BY	styleID";
					$row = WCF::getDB()->getFirstRow($sql);
					if (!empty($row['styleID'])) {
						$defaultStyle = new StyleEditor(null, $row);
						$defaultStyle->setAsDefault();
					}
				}
				
				$style->delete();
				return true;
			}			
			
			// if we won't delete it, take a look if cdata is present
			if (!isset($styleData['cdata']) || !$styleData['cdata']) {
				return false;
			}			

			// extract style tar
			$filename = $this->installation->getArchive()->extractTar($styleData['cdata'], 'style_');

			// import style
			$style = StyleEditor::import($filename, $this->installation->getPackageID(), $style);

			// set style as default
			if (isset($styleData['default'])) {
				$style->setAsDefault();
			}

			// delete tmp file
			@unlink($filename);
		}
	}

	/**
	 * This PIP has no uninstall. It's just for update purpose.
	 * 
	 * @see wcf/lib/acp/package/plugin/AbstractPackageInstallationPlugin#hasUninstall()
	 */
	public function hasUninstall()
	{
		return false;
	}
}
?>